@@ -21,29 +21,23 @@
 #if !defined(__INCLUDE_ModelStoreh_INCLUDE__)
 #define __INCLUDE_ModelStoreh_INCLUDE__
 
-#include <3dsparse/ModelID.h>
-#include <GLEXT/GLVertexSet.h>
-#include <GLEXT/GLTexture.h>
+#include <common/ModelID.h>
 #include <map>
 #include <string>
 
+class Model;
 class ModelStore
 {
 public:
 	static ModelStore *instance();
 
-	GLVertexSet *loadOrGetArray(ModelID &model,
-		bool usetextures = false, 
-		bool centreBottom = false, 
-		bool shadowModel = true);
-	GLTexture *loadTexture(const char *name, 
-		const char *aname, 
-		bool invert = false);
+	Model *loadModel(ModelID &modelId);
 
 protected:
 	static ModelStore *instance_;
-	std::map<std::string, GLVertexSet *> fileMap_;
-	std::map<std::string, GLTexture *> skins_;
+	std::map<std::string, Model *> fileMap_;
+
+	Model *getModel(ModelID &id);
 
 private:
 	ModelStore();
