@@ -26,7 +26,7 @@
 class XMLFile
 {
 public:
-	XMLFile();
+	XMLFile(bool useContentNodes = false);
 	virtual ~XMLFile();
 
 	bool readFile(const char *fileName);
