@@ -20,12 +20,13 @@
 
 #include <actions/SkyFlash.h>
 #include <engine/ScorchedContext.h>
-#include <landscape/Landscape.h>
-#include <landscape/Sky.h>
+#ifndef S3D_SERVER
+	#include <landscape/Landscape.h>
+	#include <landscape/Sky.h>
+#endif
 
-REGISTER_ACTION_SOURCE(SkyFlash);
-
-SkyFlash::SkyFlash() 
+SkyFlash::SkyFlash() :
+	ActionReferenced("SkyFlash")
 {
 }
 
@@ -37,23 +38,15 @@ void SkyFlash::init()
 {
 }
 
-void SkyFlash::simulate(float frameTime, bool &remove)
+void SkyFlash::simulate(fixed frameTime, bool &remove)
 {
+#ifndef S3D_SERVER
 	if (!context_->serverMode)
 	{
 		Landscape::instance()->getSky().flashSky();
 	}
+#endif // #ifndef S3D_SERVER
 
 	remove = true;
 	Action::simulate(frameTime, remove);
 }
-
-bool SkyFlash::writeAction(NetBuffer &buffer)
-{
-	return true;
-}
-
-bool SkyFlash::readAction(NetBufferReader &reader)
-{
-	return true;
-}
