@@ -21,6 +21,11 @@
 #if !defined(__INCLUDE_ClientMainh_INCLUDE__)
 #define __INCLUDE_ClientMainh_INCLUDE__
 
-bool clientMain();
+namespace ClientMain
+{
+	bool startClient();
+	bool clientEventLoop(float frameTime);
+	bool clientMain();
+};
 
 #endif
