@@ -21,7 +21,8 @@
 #if !defined(__INCLUDE_EventContainerh_INCLUDE__)
 #define __INCLUDE_EventContainerh_INCLUDE__
 
-#include <landscape/LandscapeTex.h>
+#include <common/fixed.h>
+#include <landscapedef/LandscapeInclude.h>
 #include <map>
 
 class EventContainer
@@ -30,11 +31,24 @@ public:
 	EventContainer();
 	virtual ~EventContainer();
 
-	void initialize(LandscapeTex *tex);
-	void simulate(float frameTime, ScorchedContext &context);
+	void clear();
+	void initialize(ScorchedContext &context);
+	void simulate(fixed frameTime, ScorchedContext &context);
 
 protected:
-	std::map<LandscapeTexEvent *, float> events_;
+	struct EventEntry
+	{
+		LandscapeEvent *event;
+		fixed eventTime;
+		int eventNumber;
+	};
+
+	std::vector<EventEntry> events_;
+
+	void addEvent(ScorchedContext &context, 
+		std::vector<LandscapeEvent *> &events);
+	void addEvents(ScorchedContext &context, 
+		std::vector<LandscapeInclude *> &events);
 };
 
 #endif // __INCLUDE_EventContainerh_INCLUDE__
