@@ -22,13 +22,14 @@
 #if !defined(__INCLUDE_DeformTexturesh_INCLUDE__)
 #define __INCLUDE_DeformTexturesh_INCLUDE__
 
-#include <landscape/DeformLandscape.h>
+#include <landscapemap/DeformLandscape.h>
+#include <common/Vector.h>
 
-class GLBitmap;
+class GLImage;
 namespace DeformTextures
 {
 	void deformLandscape(Vector &pos, float radius, 
-		bool down, GLBitmap &deformMap, 
+		GLImage &deformMap, 
 		DeformLandscape::DeformPoints &map);
 };
 
