@@ -30,7 +30,8 @@ class ServerPlayerReadyHandler :
 public:
 	static ServerPlayerReadyHandler *instance();
 
-	virtual bool processMessage(unsigned int id,
+	virtual bool processMessage(
+		NetMessage &message,
 		const char *messageType,
 		NetBufferReader &reader);
 
