@@ -22,19 +22,20 @@
 #define __INCLUDE_DebrisActionRendererh_INCLUDE__
 
 #include <common/Vector.h>
-#include <GLEXT/GLVertexSet.h>
+#include <graph/ModelRendererSimulator.h>
+#include <graph/Particle.h>
 
-class DebrisActionRenderer
+class DebrisActionRenderer : public ParticleUserData
 {
 public:
 	DebrisActionRenderer();
-	~DebrisActionRenderer();
+	virtual ~DebrisActionRenderer();
 
 	void simulate(float time);
 	void draw(Vector &position);
 
 protected:
-	GLVertexSet *debris_;
+	ModelRendererSimulator *debris_;
 	float rotationAng_;
 	float rotationX_, rotationY_, rotationZ_;
 	float rotationSpeed_;
