@@ -32,8 +32,9 @@ Parachute::~Parachute()
 {
 }
 
-bool Parachute::parseXML(OptionsGame &context,
-	AccessoryStore *store, XMLNode *accessoryNode)
+bool Parachute::parseXML(AccessoryCreateContext &context, XMLNode *accessoryNode)
 {
-	return true;
+	accessoryNode->getNamedChild("slowforce", slowForce_, false);
+
+	return accessoryNode->failChildren();
 }
